@@ -149,7 +149,14 @@ async def copy(iter, table: tables, conn: asyncpg.Connection):
         iter = aiter(iter)
     async with conn.transaction():
         logger.debug("Copying data")
-        await conn.copy_to_table(table, source=iter, columns=["content"])
+        await conn.copy_to_table(
+            table,
+            source=iter,
+            columns=["content"],
+            format="csv",
+            quote="'",
+            delimiter=chr(31),
+        )
         logger.debug("Backfilling partitions")
         await conn.execute(
             f"""
@@ -174,7 +181,12 @@ async def copy_ignore_duplicates(
         """
         )
         await conn.copy_to_table(
-            "pgstactemp", source=iter, columns=["content"]
+            "pgstactemp",
+            source=iter,
+            columns=["content"],
+            format="csv",
+            quote="'",
+            delimiter=chr(31),
         )
         logger.debug("Data Copied")
         await conn.execute(
@@ -209,7 +221,12 @@ async def copy_upsert(iter, table: tables, conn: asyncpg.Connection):
         """
         )
         await conn.copy_to_table(
-            "pgstactemp", source=iter, columns=["content"]
+            "pgstactemp",
+            source=iter,
+            columns=["content"],
+            format="csv",
+            quote="'",
+            delimiter=chr(31),
         )
         logger.debug("Data Copied")
         if table == "collections":
